<?php

use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

$app_url = config("app.url");
if (!empty($app_url)) {
    URL::forceRootUrl($app_url);

    $schema = explode(':', $app_url)[0];
    URL::forceScheme($schema);
}

Route::get('/', function () {
    return redirect(action('MarkController@rankingHome'));
});

Auth::routes(['register' => false]);

Route::prefix('app')
        ->middleware('auth')
        ->group(function () {
            Route::get('status', 'MarkController@status')->name('status');
            Route::get('status/data', 'MarkController@lastData');
            Route::get('status/evidences', 'MarkController@lastEvidences');
            Route::get('pause', 'MarkController@pause')->name('pause');
            Route::get('resume', 'MarkController@resume')->name('resume');
            Route::get('reload', 'MarkController@reload')->name('reload');

            Route::get('ranking', 'MarkController@rankingHome');
            Route::get('ranking/{label}', 'MarkController@ranking');
            Route::get('ranking/{label}/csv', 'MarkController@rankingCSV');
            Route::get('ranking/{label}/json', 'MarkController@rankingJSON');
            Route::get('ranking/{label}/bubble', 'MarkController@bubble');
            Route::get('ranking/{label}/radar', 'MarkController@radar');

            Route::get('evidence/{id}/data/{data_id}', 'MarkController@evidenceData');
            Route::get('evidence/{id}', 'MarkController@evidence');
            Route::get('evidence/{id}/false-alarm', 'MarkController@falseAlarm');
            Route::get('evidence/{id}/true-detection', 'MarkController@trueDetection');

            // display an error
            // this route is actually triggered by app/Mark.php
            Route::get('error', 'MarkController@error');
        });

Route::get('data/{file}', 'DataController@show')->middleware('auth');

Route::prefix('api')->group(function () {
    Route::get('status', function () {
        $c = new \Cylab\Mark\Client();
        return $c->status();
    });
});

Route::prefix('admin')
        ->middleware('admin')
        ->group(function () {
            Route::resource('users', 'UserController');
            Route::get('users/{user}/toggle', 'UserController@toggleAdmin');
            Route::resource('feedback', 'FeedbackController');
            Route::get('populate', 'FeedbackController@populate');
            Route::get('dropFeedback', 'FeedbackController@dropFeedbacks');
            Route::get('dropWowa', 'WowaController@dropWowas');
            Route::resource('wowas', 'WowaController');
            Route::get('wowas/{wowa}/load', 'WowaController@loadParameters');
        });
